#!/usr/bin/env bash

echo "$@"
echo 'Hello World'
